pub enum DmaCoherency {
Coherent,
NonCoherent,
}Expand description
Cache-coherency relationship between one DMA device and the CPU.
This is a device property supplied by firmware or the platform bus. It is independent from address-mask and segment-layout constraints.
Variants
Coherent
CPU and device observe the same cacheable mapping without explicit cache maintenance.
NonCoherent
CPU ownership transitions require cache maintenance or a coherent CPU mapping supplied by the DMA backend.