CoherentArray

Struct CoherentArray 

pub struct CoherentArray<T: DmaPod> { /* private fields */ }

Implementations

Source

impl<T: DmaPod> CoherentArray<T>

pub fn dma_addr(&self) -> DmaAddr

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn bytes_len(&self) -> usize

pub fn read_cpu(&self, index: usize) -> Option<T>

pub fn set_cpu(&mut self, index: usize, value: T)

pub fn copy_from_slice_cpu(&mut self, src: &[T])

pub fn iter_cpu(&self) -> ArrayCpuIter<'_, T, Self>

pub fn write_with_cpu<R>( &mut self, len: usize, f: impl FnOnce(&mut [T]) -> R, ) -> R

pub fn read_with_cpu<R>(&self, len: usize, f: impl FnOnce(&[T]) -> R) -> R

pub fn as_ptr(&self) -> NonNull<T>

pub fn as_slice_cpu(&self) -> &[T]

pub unsafe fn as_mut_slice_cpu(&mut self) -> &mut [T]

Safety

The caller must ensure the device is not concurrently accessing this memory in a way that races with CPU writes.