pub struct CoherentBox<T: DmaPod> { /* private fields */ }Implementations
Sourceimpl<T: DmaPod> CoherentBox<T>
impl<T: DmaPod> CoherentBox<T>
pub fn dma_addr(&self) -> DmaAddr
pub fn read_cpu(&self) -> T
pub fn write_cpu(&mut self, value: T)
pub fn modify_cpu(&mut self, f: impl FnOnce(&mut T))
pub fn as_ptr(&self) -> NonNull<T>
Sourcepub unsafe fn as_bytes_mut_cpu(&mut self) -> &mut [u8] ⓘ
pub unsafe fn as_bytes_mut_cpu(&mut self) -> &mut [u8] ⓘ
Safety
The caller must ensure the device is not concurrently accessing this memory in a way that races with CPU writes.