pub struct DmaDomainId(/* private fields */);Expand description
Stable identity for one DMA translation domain.
Drivers use this to reject already-prepared DMA buffers that were prepared for a different device/IOMMU domain.
Implementations
Sourceimpl DmaDomainId
impl DmaDomainId
pub const fn new(id: NonZeroU64) -> Self
Sourcepub const fn legacy_global() -> Self
pub const fn legacy_global() -> Self
Compatibility domain for legacy callers that have not plumbed a device/IOMMU-specific identity yet.
pub fn from_raw(id: u64) -> Self
pub const fn get(self) -> NonZeroU64