PreparedDma

Struct PreparedDma 

pub struct PreparedDma { /* private fields */ }
DMA backing prepared for device access but not yet owned by hardware.

Implementations

Source

impl PreparedDma

pub fn len(&self) -> NonZeroUsize

pub const fn direction(&self) -> DmaDirection

pub const fn domain_id(&self) -> DmaDomainId

pub fn cpu_ptr(&self) -> NonNull<u8>

pub fn dma_addr(&self) -> DmaAddr

pub fn segment(&self) -> DmaSegment

pub fn segments(&self) -> [DmaSegment; 1]

pub fn into_cpu_buffer(self) -> CpuDmaBuffer

pub unsafe fn into_in_flight(self) -> InFlightDma

Safety

The caller must start hardware ownership using this prepared backing and later return it only after hardware is quiesced.