DmaPod

Trait DmaPod 

pub unsafe trait DmaPod: Copy { }
Marker for plain data that can be safely stored in typed DMA buffers.

Safety

Implementors must be Copy, have no invalid all-zero bit pattern, and must not own resources or references whose validity can be broken by raw device writes.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T: Copy> DmaPod for T